LanceDbVectorIndex

Struct LanceDbVectorIndex 

pub struct LanceDbVectorIndex<M: EmbeddingModel> { /* private fields */ }
Type on which vector searches can be performed for a lanceDb table.

Example

use rig_lancedb::{LanceDbVectorIndex, SearchParams};
use rig::providers::openai::{Client, TEXT_EMBEDDING_ADA_002, EmbeddingModel};

let openai_client = Client::from_env();

let table: lancedb::Table = db.create_table(""); // <-- Replace with your lancedb table here.
let model: EmbeddingModel = openai_client.embedding_model(TEXT_EMBEDDING_ADA_002); // <-- Replace with your embedding model here.
let vector_store_index = LanceDbVectorIndex::new(table, model, "id", SearchParams::default()).await?;

Implementations

Source

impl<M> LanceDbVectorIndex<M>
where M: EmbeddingModel,

pub async fn new( table: Table, model: M, id_field: &str, search_params: SearchParams, ) -> Result<Self, Error>

Create an instance of LanceDbVectorIndex with an existing table and model. Define the id field name of the table. Define search parameters that will be used to perform vector searches on the table.