pub struct SearchParams { /* private fields */ }Expand description
Parameters used to perform a vector search on a LanceDb table.
Example
let search_params = rig_lancedb::SearchParams::default().distance_type(lancedb::DistanceType::Cosine);Implementations
Sourceimpl SearchParams
impl SearchParams
Sourcepub fn distance_type(self, distance_type: DistanceType) -> Self
pub fn distance_type(self, distance_type: DistanceType) -> Self
Sets the distance type of the search params. Always set the distance_type to match the value used to train the index. The default is DistanceType::L2.
Sourcepub fn search_type(self, search_type: SearchType) -> Self
pub fn search_type(self, search_type: SearchType) -> Self
Sets the search type of the search params. By default, ANN will be used if there is an index on the table and kNN will be used if there is NO index on the table. To use the mentioned defaults, do not set the search type.
Sourcepub fn nprobes(self, nprobes: usize) -> Self
pub fn nprobes(self, nprobes: usize) -> Self
Sets the nprobes of the search params. Only set this value only when the search type is ANN. See LanceDb ANN Search for more information.
Sourcepub fn refine_factor(self, refine_factor: u32) -> Self
pub fn refine_factor(self, refine_factor: u32) -> Self
Sets the refine factor of the search params. Only set this value only when search type is ANN. See LanceDb ANN Search for more information.
Sourcepub fn post_filter(self, post_filter: bool) -> Self
pub fn post_filter(self, post_filter: bool) -> Self
Sets the post filter of the search params. If set to true, filtering will happen after the vector search instead of before. See LanceDb pre/post filtering for more information.